package com.xhkjedu.sapi.service.research;

import com.xhkjedu.sapi.listener.MessageSender;
import com.xhkjedu.sapi.mapper.research.ResearchMapper;
import com.xhkjedu.sapi.mapper.research.ResearchUserMapper;
import com.xhkjedu.sapi.model.research.TResearchUser;
import com.xhkjedu.sapi.vo.research.ResearchUserVo;
import com.xhkjedu.utils.N_Utils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName ResearchUserService
 * Description TODO
 * Author WN
 * Date 2020/6/11 19:34
 **/
@Service
public class ResearchUserService {
    @Autowired
    private ResearchUserMapper researchUserMapper;
    @Autowired
    private ResearchMapper researchMapper;
    @Autowired
    private MessageSender messageSender;

    /**
     * 功能描述  参与评论集合
     *
     * @param * @param researchid
     * @return java.util.List<com.xhkjedu.model.research.TResearchUser>
     * @author WN
     * @date 2020/6/11
     */
    public List<Map> listRusersByReaearchid(Integer researchid, Integer schoolid) {
        return researchUserMapper.listRusersByReaearchid(researchid, schoolid);
    }

    /**
     * 功能描述 教师--参与教研集合
     *
     * @param *      @param userid
     * @param rorder
     * @return java.util.List<com.xhkjedu.vo.research.ResearchVo>
     * @author WN
     * @date 2020/6/12
     */
    public List<Map> listUserResearchs(Integer userid, String rorder, Integer rustate) {
        return researchUserMapper.listUserResearchs(userid, rorder, rustate, N_Utils.getSecondTimestamp());
    }

    /**
     * 功能描述 教师--获取教研详情
     *
     * @param * @param researchid
     * @return com.xhkjedu.model.research.TResearch
     * @author WN
     * @date 2020/6/12
     */
    public ResearchUserVo getResearchUserDetail(Integer researchid, Integer userid) {
        ResearchUserVo researchUserVo = researchUserMapper.getResearchUserDetail(researchid, userid);
        // 更改阅读次数
        researchMapper.updateReadnum(researchid);

        // 视频转换mq
        if (!researchUserVo.getMp4code().equals("h264")) {
            messageSender.convertVideo(researchUserVo.getResearchid(), researchUserVo.getResearchpath());
        }

        // 如果教研是公开的，则获取所有已提交教研
        if (researchUserVo.getPubliced() == 0) {
            List<Map> schools = researchUserMapper.listReaearchSchools(researchid, researchUserVo.getSchoolid());
            // 去除学校中未参与评价教师
            for (int i = 0; i < schools.size(); i++) {
                List<Map> commitRusers = new ArrayList<>();
                List<Map> rusers = (List<Map>) schools.get(i).get("rusers");
                for (int j = 0; j < rusers.size(); j++) {
                    Map map = rusers.get(j);
                    Integer rustate = Integer.parseInt(map.get("rustate").toString());
                    if(rustate!=null && rustate == 1){
                        commitRusers.add(map);
                    }
                }
                schools.get(i).put("rusers",commitRusers);
            }
            researchUserVo.setSchools(schools);
        }

        return researchUserVo;
    }

    /**
     * 功能描述 教师--保存教研评价
     *
     * @param * @param ru
     * @return java.lang.Integer
     * @author WN
     * @date 2020/6/12
     */
    public Integer updateUserResearch(TResearchUser ru) {
        ru.setRustate(1);// 状态0未评1已评
        ru.setReviewtime(N_Utils.getSecondTimestamp());
        return researchUserMapper.updateUserResearch(ru);
    }

    /**
     * 其他教研活动列表
     *
     * @return java.util.List<com.xhkjedu.vo.research.ResearchVo>
     * @Param [research]
     * @Author ywx
     * @Date 2020/6/23 14:24
     **/
    public List<Map> otherList(TResearchUser research) {
        research.setCreatetime(N_Utils.getSecondTimestamp());
        return researchUserMapper.otherList(research);
    }

    /**
     * 教师未评价教研数量
     *
     * @return java.lang.Integer
     * @Param [userid]
     * @Author ywx
     * @Date 2020/7/24 10:45
     **/
    public Integer noEvaluatedNum(Integer userid) {
        return researchUserMapper.noEvaluatedNum(userid, N_Utils.getSecondTimestamp());
    }
}
